==> huaweicloudsdkcae-3.1.108-py2.py3-none-any.whl: huaweicloudsdkcae/v1/region/cae_region.py <==
# coding: utf-8

from huaweicloudsdkcore.region.region import Region
from huaweicloudsdkcore.region.provider import RegionProviderChain

class CaeRegion:
    _PROVIDER = RegionProviderChain.get_default_region_provider_chain("CAE")

    CN_NORTH_4 = Region("cn-north-4",
                        "https://cae.cn-north-4.myhuaweicloud.com")
    CN_EAST_3 = Region("cn-east-3",
                        "https://cae.cn-east-3.myhuaweicloud.com")
    CN_SOUTH_1 = Region("cn-south-1",
                        "https://cae.cn-south-1.myhuaweicloud.com")
    AP_SOUTHEAST_3 = Region("ap-southeast-3",
                        "https://cae.ap-southeast-3.myhuaweicloud.com")
    AF_SOUTH_1 = Region("af-south-1",
                        "https://cae.af-south-1.myhuaweicloud.com")

    static_fields = {
        "cn-north-4": CN_NORTH_4,
        "cn-east-3": CN_EAST_3,
        "cn-south-1": CN_SOUTH_1,
        "ap-southeast-3": AP_SOUTHEAST_3,
        "af-south-1": AF_SOUTH_1,
    }

    @classmethod
    def value_of(cls, region_id, static_fields=None):
        if not region_id:
            raise KeyError("Unexpected empty parameter: region_id")

        fields = static_fields or cls.static_fields

        region = cls._PROVIDER.get_region(region_id)
        if region:
            return region

        if region_id in fields:
            return fields.get(region_id)

        raise KeyError("region_id '%s' is not in the following supported regions of service 'Cae': [%s]" % (
            region_id, ", ".join(sorted(fields.keys()))))

==> huaweicloudsdkcae-3.1.138-py2.py3-none-any.whl: huaweicloudsdkcae/v1/region/cae_region.py <==
# coding: utf-8

from huaweicloudsdkcore.region.region import Region
from huaweicloudsdkcore.region.provider import RegionProviderChain

class CaeRegion:
    _PROVIDER = RegionProviderChain.get_default_region_provider_chain("CAE")

    CN_NORTH_4 = Region("cn-north-4",
                        "https://cae.cn-north-4.myhuaweicloud.com",
                        "https://cae.cn-north-4.myhuaweicloud.cn")
    CN_EAST_3 = Region("cn-east-3",
                        "https://cae.cn-east-3.myhuaweicloud.com",
                        "https://cae.cn-east-3.myhuaweicloud.cn")
    CN_SOUTH_1 = Region("cn-south-1",
                        "https://cae.cn-south-1.myhuaweicloud.com",
                        "https://cae.cn-south-1.myhuaweicloud.cn")
    AP_SOUTHEAST_3 = Region("ap-southeast-3",
                        "https://cae.ap-southeast-3.myhuaweicloud.com",
                        "https://cae.ap-southeast-3.myhuaweicloud.cn")
    AF_SOUTH_1 = Region("af-south-1",
                        "https://cae.af-south-1.myhuaweicloud.com",
                        "https://cae.af-south-1.myhuaweicloud.cn")

    static_fields = {
        "cn-north-4": CN_NORTH_4,
        "cn-east-3": CN_EAST_3,
        "cn-south-1": CN_SOUTH_1,
        "ap-southeast-3": AP_SOUTHEAST_3,
        "af-south-1": AF_SOUTH_1,
    }

    @classmethod
    def value_of(cls, region_id, static_fields=None):
        if not region_id:
            raise KeyError("Unexpected empty parameter: region_id")

        fields = static_fields or cls.static_fields

        region = cls._PROVIDER.get_region(region_id)
        if region:
            return region

        if region_id in fields:
            return fields.get(region_id)

        raise KeyError("region_id '%s' is not in the following supported regions of service 'Cae': [%s]" % (
            region_id, ", ".join(sorted(fields.keys()))))
